<?php
/*
================================================================================================
Tifology - functions.php
================================================================================================
This is the most generic template file in a WordPress theme and is one of the two required files 
for a theme (the other being template-tags.php). This file is used to maintain the main 
functionality and features for this theme. The second file is the template-tags.php that contains 
the extra functions and features.

@package        Tifology WordPress Theme
@copyright      Copyright (C) 2015. Benjamin Lu
@license        GNU General Public License v2 or later (http://www.gnu.org/licenses/gpl-2.0.html)
@author         Benjamin Lu (http://luminathemes.com/contact/
@since          0.0.1
================================================================================================
*/

/*
================================================================================================
Table of Content
================================================================================================
1.0 - Content Width
2.0 - Required Files
3.0 - Enqueue Styles and Scripts
4.0 - Main Theme Setup
================================================================================================
*/

/*
================================================================================================
1.0 - Content Width
================================================================================================
*/
if (!isset($content_width)) {
    $content_width = 800;
}


/*
================================================================================================
2.0 - Required Files
================================================================================================
*/
require(get_template_directory() . '/includes/custom-header.php');
require(get_template_directory() . '/includes/template-tags.php');
require(get_template_directory() . '/includes/customizer.php');

/*
================================================================================================
3.0 - Enqueue Styles and Scripts
================================================================================================
*/
if (!function_exists('tifology_scripts_setup')) {
    function tifology_scripts_setup() {
        //Enable Default Style CSS
        wp_enqueue_style('tifology-style', get_stylesheet_uri());
        
        // Enable Google Font for Ubuntu
        wp_enqueue_style('tifology-google-ubuntu', '//fonts.googleapis.com/css?family=Ubuntu:300,400,500,700,300italic,400italic,500italic,700italic');
        
        // Enable Font Awesome
        wp_enqueue_style('tifology-font-awesome', get_stylesheet_directory_uri() . '/extras/font-awesome/css/font-awesome.css', '03302015', true);
        
        // Enable Navigation
        wp_enqueue_script('tifology-navigation-js', get_template_directory_uri() . '/js/navigation.js', array('jquery'), '04062015', true);
        
        if (is_singular() && comments_open() && get_option('thread_comments'))
                wp_enqueue_script( 'comment-reply' );
    
    }
    add_action('wp_enqueue_scripts', 'tifology_scripts_setup');
}
/*
================================================================================================
4.0 - Main Theme Setup
================================================================================================
*/
if (!function_exists('tifology_theme_setup')) {
    function tifology_theme_setup() {
        // Enable Add Theme Support for Title Tag
        add_theme_support('title-tag');
        
        // Enable Add Theme Support for HTML5
        add_theme_support('html5', array('search-form', 'caption'));
        
        // Enable Custom Background and Image
        $args = array(
            'default-color' => '000000',
        );
        add_theme_support( 'custom-background', $args );
        
        // Enable Add Theme Support for Automatic Feed Links
        add_theme_support('automatic-feed-links');
        
        load_theme_textdomain( 'tifology', get_template_directory() . '/languages' );
        
        register_nav_menus(array(
            'primary-navigation' => esc_html__('Primary Navigation', 'tifology'),
        ));
    }
    add_action('after_setup_theme', 'tifology_theme_setup');
}